==> beast-privilege-api-2.6.6-20230316.071008-7-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class KeyMemberMemorialVO implements Serializable {
    private Integer id;
    private Integer memberId; //会员ID
    private String memberCode; //会员编码
    private String cellPhone; //手机号
    private String nickName; //会员昵称
    private String channelCode; //负责店铺
    private Integer channelChargeId; //负责人
    private String remark; //备注
    private Integer dateSourse; //数据来源 1：页面添加 2：DB导入
    private Integer isDataPerfect; //数据是否完善（record表有数据代表完善） 1：是 0：否
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;


    private List<KeyMemberMemorialRecordVO> recordVOList;




    public Integer getId() {
        return id;
    }


    public void setId(Integer id) {
        this.id = id;
    }


    public Integer getMemberId() {
        return memberId;
    }


    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }


    public String getMemberCode() {
        return memberCode;
    }


    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }


    public String getCellPhone() {
        return cellPhone;
    }


    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }


    public String getNickName() {
        return nickName;
    }


    public void setNickName(String nickName) {
        this.nickName = nickName;
    }


    public String getChannelCode() {
        return channelCode;
    }


    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }


    public Integer getChannelChargeId() {
        return channelChargeId;
    }


    public void setChannelChargeId(Integer channelChargeId) {
        this.channelChargeId = channelChargeId;
    }


    public String getRemark() {
        return remark;
    }


    public void setRemark(String remark) {
        this.remark = remark;
    }


    public Integer getDateSourse() {
        return dateSourse;
    }


    public void setDateSourse(Integer dateSourse) {
        this.dateSourse = dateSourse;
    }


    public Integer getIsDataPerfect() {
        return isDataPerfect;
    }


    public void setIsDataPerfect(Integer isDataPerfect) {
        this.isDataPerfect = isDataPerfect;
    }


    public Date getCreateTime() {
        return createTime;
    }


    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }


    public Date getUpdateTime() {
        return updateTime;
    }


    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }


    public Integer getCreatorId() {
        return creatorId;
    }


    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }


    public String getCreatorName() {
        return creatorName;
    }


    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public List<KeyMemberMemorialRecordVO> getRecordVOList() {
        return recordVOList;
    }

    public void setRecordVOList(List<KeyMemberMemorialRecordVO> recordVOList) {
        this.recordVOList = recordVOList;
    }


}

==> beast-privilege-api-2.6.6-20230320.060605-10-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

public class KeyMemberMemorialVO implements Serializable {
    private Integer id;
    private Integer memberId; //会员ID
    private String memberCode; //会员编码
    private String cellPhone; //手机号
    private String nickName; //会员昵称
    private String channelCode; //负责店铺
    private Integer channelChargeId; //负责人
    private String remark; //备注
    private Integer dateSourse; //数据来源 1：页面添加 2：DB导入
    private Integer isDataPerfect; //数据是否完善（record表有数据代表完善） 1：是 0：否
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;



    /*
          储值余额
         */
    private BigDecimal storedValueBalance;


    private String channelName;
    private String channelChargeName;
    private String memberLevelName;



    private List<KeyMemberMemorialRecordVO> recordVOList;




    public Integer getId() {
        return id;
    }


    public void setId(Integer id) {
        this.id = id;
    }


    public Integer getMemberId() {
        return memberId;
    }


    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }


    public String getMemberCode() {
        return memberCode;
    }


    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }


    public String getCellPhone() {
        return cellPhone;
    }


    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }


    public String getNickName() {
        return nickName;
    }


    public void setNickName(String nickName) {
        this.nickName = nickName;
    }


    public String getChannelCode() {
        return channelCode;
    }


    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }


    public Integer getChannelChargeId() {
        return channelChargeId;
    }


    public void setChannelChargeId(Integer channelChargeId) {
        this.channelChargeId = channelChargeId;
    }


    public String getRemark() {
        return remark;
    }


    public void setRemark(String remark) {
        this.remark = remark;
    }


    public Integer getDateSourse() {
        return dateSourse;
    }


    public void setDateSourse(Integer dateSourse) {
        this.dateSourse = dateSourse;
    }


    public Integer getIsDataPerfect() {
        return isDataPerfect;
    }


    public void setIsDataPerfect(Integer isDataPerfect) {
        this.isDataPerfect = isDataPerfect;
    }


    public Date getCreateTime() {
        return createTime;
    }


    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }


    public Date getUpdateTime() {
        return updateTime;
    }


    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }


    public Integer getCreatorId() {
        return creatorId;
    }


    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }


    public String getCreatorName() {
        return creatorName;
    }


    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public BigDecimal getStoredValueBalance() {
        return storedValueBalance;
    }

    public void setStoredValueBalance(BigDecimal storedValueBalance) {
        this.storedValueBalance = storedValueBalance;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getChannelChargeName() {
        return channelChargeName;
    }

    public void setChannelChargeName(String channelChargeName) {
        this.channelChargeName = channelChargeName;
    }

    public String getMemberLevelName() {
        return memberLevelName;
    }

    public void setMemberLevelName(String memberLevelName) {
        this.memberLevelName = memberLevelName;
    }


    public List<KeyMemberMemorialRecordVO> getRecordVOList() {
        return recordVOList;
    }

    public void setRecordVOList(List<KeyMemberMemorialRecordVO> recordVOList) {
        this.recordVOList = recordVOList;
    }


}
